
.. currentmodule:: sardana.macroserver.macro

.. _sardana-macro-api:

===================
Macro API reference
===================

Macro class
-----------

.. autoclass:: Macro
    :members:
    :undoc-members:

iMacro class
------------

.. autoclass:: iMacro
    :members:
    :undoc-members:

macro decorator
---------------

.. autoclass:: macro
    :members:
    :undoc-members:
    
imacro decorator
----------------

.. autoclass:: imacro
    :members:
    :undoc-members:

